@@ -5,7 +5,7 @@ urlpatterns = patterns('',
     url(r'^$',
         popular.top_authors,
         name='cab_top_authors'),
-    url(r'^(?P<username>[-\w]+)/$',
+    url(r'^(?P<username>[\w.@+-]+)/$',
         snippets.author_snippets,
         name='cab_author_snippets'),
 )
